@@ -8,15 +8,15 @@ _ForkingPickler = context.reduction.ForkingPickler
 def rebuild_queue(newstate, message_buffer_size):
     q = faster_fifo.Queue.__new__(faster_fifo.Queue)
     q.__dict__.update(newstate)
+    q.message_buffer = faster_fifo.TLSBuffer(None)
     q.reallocate_msg_buffer(message_buffer_size)
     return q
 
 
 def reduce_queue(q):
     state = q.__dict__.copy()
-    message_buffer_size = 0 if q.message_buffer is None else len(q.message_buffer)
+    message_buffer_size = 0 if q.message_buffer.val is None else len(q.message_buffer.val)
     state['message_buffer'] = None
-    state['message_buffer_memview'] = None
     return rebuild_queue, (state, message_buffer_size)
 
 
